# youtubemeta
Download data from YouTube channels - Video titles, view counts, dates, and URLs

To get started  

`pip install youtubemeta`

Then import the module and run for the channel  

```
import youtubemeta  
youtubemeta.scrape('CHANNEL_NAME')
```

Arguments

```
--write    write to CSV
--path     specify custom path and filename for the csv
```
